@@ -18,8 +18,8 @@
 
 // Version of the language:
 #define OSL_VERSION_MAJOR 1
-#define OSL_VERSION_MINOR 11
-#define OSL_VERSION_PATCH 17
+#define OSL_VERSION_MINOR 12
+#define OSL_VERSION_PATCH 9
 #define OSL_VERSION_TWEAK 0
 #define OSL_VERSION (10000 * OSL_VERSION_MAJOR + \
                                100 * OSL_VERSION_MINOR + \
@@ -27,8 +27,8 @@
 
 // Version of this library:
 #define OSL_LIBRARY_VERSION_MAJOR 1
-#define OSL_LIBRARY_VERSION_MINOR 11
-#define OSL_LIBRARY_VERSION_PATCH 17
+#define OSL_LIBRARY_VERSION_MINOR 12
+#define OSL_LIBRARY_VERSION_PATCH 9
 #define OSL_LIBRARY_VERSION_TWEAK 0
 #define OSL_LIBRARY_VERSION_RELEASE_TYPE 
 
@@ -36,13 +36,14 @@
                                     100 * OSL_VERSION_MINOR + \
                                           OSL_VERSION_PATCH)
 
-// Magic macros to make OSL_LIBRARY_VERSION_STRING that looks like "1.2.3"
-#define OSL_MAKE_VERSION_STRING2(a,b,c,d) #a "." #b "." #c #d
-#define OSL_MAKE_VERSION_STRING(a,b,c,d) OSL_MAKE_VERSION_STRING2(a,b,c,d)
+// Magic macros to make OSL_LIBRARY_VERSION_STRING that looks like "1.2.3.0"
+#define OSL_MAKE_VERSION_STRING2(a,b,c,d,e) #a "." #b "." #c "." #d #e
+#define OSL_MAKE_VERSION_STRING(a,b,c,d,e) OSL_MAKE_VERSION_STRING2(a,b,c,d,e)
 #define OSL_LIBRARY_VERSION_STRING \
     OSL_MAKE_VERSION_STRING(OSL_LIBRARY_VERSION_MAJOR, \
                             OSL_LIBRARY_VERSION_MINOR, \
                             OSL_LIBRARY_VERSION_PATCH, \
+                            OSL_LIBRARY_VERSION_TWEAK, \
                             OSL_LIBRARY_VERSION_RELEASE_TYPE)
 #define OSL_INTRO_STRING "Open Shading Language " OSL_LIBRARY_VERSION_STRING
 #define OSL_COPYRIGHT_STRING "Copyright Contributors to the Open Shading Language project."
@@ -65,13 +66,13 @@
 
 
 // Establish the name spaces
-namespace OSL_v1_11 { }
-namespace OSL = OSL_v1_11;
+namespace OSL_v1_12 { }
+namespace OSL = OSL_v1_12;
 
 // Macros to use in each file to enter and exit the right name spaces.
-#define OSL_NAMESPACE OSL_v1_11
-#define OSL_NAMESPACE_STRING "OSL_v1_11"
-#define OSL_NAMESPACE_ENTER namespace OSL_v1_11 {
+#define OSL_NAMESPACE OSL_v1_12
+#define OSL_NAMESPACE_STRING "OSL_v1_12"
+#define OSL_NAMESPACE_ENTER namespace OSL_v1_12 {
 #define OSL_NAMESPACE_EXIT }
 
 
@@ -86,4 +87,23 @@ namespace OSL = OSL_v1_11;
 
 #define OSL_SHADER_INSTALL_DIR "/usr/share/OSL/shaders"
 
+// Macro helpers to build function names based on other macros
+#define __OSL_CONCAT_INDIRECT(A, B) A ## B
+#define __OSL_CONCAT(A, B) __OSL_CONCAT_INDIRECT(A,B)
+#define __OSL_CONCAT3(A, B, C) __OSL_CONCAT(__OSL_CONCAT(A,B),C)
+#define __OSL_CONCAT4(A, B, C, D) __OSL_CONCAT(__OSL_CONCAT3(A,B,C),D)
+#define __OSL_CONCAT5(A, B, C, D, E) __OSL_CONCAT(__OSL_CONCAT4(A,B,C,D),E)
+#define __OSL_CONCAT6(A, B, C, D, E, F) __OSL_CONCAT(__OSL_CONCAT5(A,B,C,D,E),F)
+#define __OSL_CONCAT7(A, B, C, D, E, F, G) __OSL_CONCAT(__OSL_CONCAT6(A,B,C,D,E,F),G)
+#define __OSL_CONCAT8(A, B, C, D, E, F, G, H) __OSL_CONCAT(__OSL_CONCAT7(A,B,C,D,E,F,G),H)
+#define __OSL_CONCAT9(A, B, C, D, E, F, G, H, I) __OSL_CONCAT(__OSL_CONCAT8(A,B,C,D,E,F,G,H),I)
+#define __OSL_CONCAT10(A, B, C, D, E, F, G, H, I, J) __OSL_CONCAT(__OSL_CONCAT9(A,B,C,D,E,F,G,H,I),J)
+
+#if defined(__OSL_TARGET_ISA) && defined(__OSL_WIDTH)
+    #define __OSL_WIDE_PVT __OSL_CONCAT5(b,__OSL_WIDTH,_,__OSL_TARGET_ISA,_pvt)
+#endif
+
+#define __OSL_INDIRECT_STRINGIFY(x) #x
+#define __OSL_STRINGIFY(x) __OSL_INDIRECT_STRINGIFY(x)
+
 #endif /* OSLVERSION_H */
